@@ -13,29 +13,28 @@ from . import util
 
 l = logging.getLogger("pandem-admin")
 
-def reset_variables(in_package = False, in_home = True):
-  if in_package:
-    write_json_variables( pkg_resources.resource_filename("pandemsource", "data/DLS/variables.json"))
-  if in_home:
-    dir_path = util.pandem_path("files", "variables")
-    file_path = util.pandem_path("files", "variables", "variables.json")
-    if not os.path.exists(dir_path):
-      os.makedirs(dir_path)
-    # copy variables json fils and indicators
-    write_json_variables(file_path)
+def reset_variables():
+  dir_path = util.pandem_path("files", "variables")
+  home_path = util.pandem_path("files", "variables", "variables.csv")
+  if not os.path.exists(dir_path):
+    os.makedirs(dir_path)
+  pkg_path = pkg_resources.resource_filename("pandemsource", "data/list-of-variables.csv")
+  shutil.copy(pkg_path, home_path)
+  # rewriting default variables
+  reset_default_folders("variables", "indicators", delete_existing = False)
 
-def reset_default_folders(*folders):
+def reset_default_folders(*folders, delete_existing = True):
   # copy default data from data folder
   for folder in folders:
     if pkg_resources.resource_exists("pandemsource", f"data/{folder}"):
       var_from = pkg_resources.resource_filename("pandemsource", os.path.join("data", folder))
       var_to = util.pandem_path("files", folder)
-      if os.path.exists(var_to):
+      if os.path.exists(var_to) and delete_existing:
         shutil.rmtree(var_to)
-      shutil.copytree(var_from, var_to, copy_function = shutil.copy)
+      shutil.copytree(var_from, var_to, copy_function = shutil.copy, dirs_exist_ok = True)
 
 def read_variables_definitions():
-  path = pkg_resources.resource_filename("pandemsource", "data/list-of-variables.csv")
+  path = util.pandem_path("files", "variables", "variables.csv")
   df = pd.read_csv(path, encoding = "ISO-8859-1")
   df = df.rename(columns = {
     "Variable":"variable", 
@@ -56,18 +55,9 @@ def read_variables_definitions():
       df[col] = df[col].str.split(",")
     if col == "modifiers":
       df[col] = df[col].apply(lambda x : json.loads(x))
-  return df
-
-def write_json_variables(dest):
-  df = read_variables_definitions()
-  path = dest
   result = df.to_json(orient = "records")
   parsed = json.loads(result)
-  j = json.dumps(parsed, indent=2)
-
-  file = codecs.open(path, "w", "utf-8")
-  file.write(j)
-  file.close()
+  return parsed
 
 def reset_source(source_name):
   dls_from = pkg_resources.resource_filename("pandemsource", os.path.join("data", "DLS", f"{source_name}.json"))
@@ -94,6 +84,14 @@ def reset_source(source_name):
       os.makedirs(script_to_dir)
     shutil.copyfile(script_from, script_to)
 
+  # Copy the corresponding Python script from package to pandem-home
+  pyscript_fol = pkg_resources.resource_filename("pandemsource", os.path.join("data", "scripts", "py", "sources"))
+  dls_pyscript = dls["scope"]["source"].replace("-", "_").replace(" ", "_") + ".py"
+  pyscript_to = util.pandem_path("files", "scripts", "py", "sources", dls_pyscript)
+  if dls_pyscript in os.listdir(pyscript_fol):
+    shutil.copyfile(os.path.join(pyscript_fol, dls_pyscript), pyscript_to)
+
+
 def delete_all():
     if os.path.exists(util.pandem_path("settings.yml")):
       os.remove(util.pandem_path("settings.yml"))
@@ -109,10 +107,10 @@ def install_issues(check_nlp = True):
   if shutil.which("R") is None:
     ret.append["Cannot find R language. Please installe it. PANDEM2 needs it to calculate indecators"]
   else:
-    r_packages = '"epitweetr", "dplyr", "shiny", "plotly", "DT", "jsonlite", "httr"'
+    r_packages = '"dplyr", "shiny", "plotly", "DT", "jsonlite", "httr", "XML", "ggplot2"'
     installed = subprocess.run(['R', '-e', f'if(length(setdiff(c({r_packages}), names(installed.packages()[,1])))> 0) stop("some packages are missing!!")'], stdout=FNULL, stderr=FNULL).returncode
     if installed == 1:
-      ret.append(f'Cannot find some necessary R packages, please intalle them from CRAN, by running install.packages(c({r_packages}))')
+      ret.append(f'Cannot find some necessary R packages, please intall them from CRAN, by running install.packages(c({r_packages}))')
     installed = subprocess.run(['R', '-e', f'if(length(setdiff(c(), names(installed.packages("COVID19")[,1])))> 0) stop("some packages are missing!!")'], stdout=FNULL, stderr=FNULL).returncode
     if installed == 1:
       ret.append(f"""Cannot find COVID19 R packages necessary for getting COVID19 data hub data. 
@@ -120,6 +118,14 @@ def install_issues(check_nlp = True):
         install.packages("devtools")
         devtools::install_github(repo = "covid19datahub/COVID19", ref = "b941b66e59b7b0aec4807eb5b28208abba66de4a", upgrade = "never")
       If you prefer downloading data prepared by COVID data hub tem you can install it from CRAN, by running install.packages(c("COVID19"))""")
+    installed = subprocess.run(['R', '-e', f'if(length(setdiff(c(), names(installed.packages("Pandem2simulator")[,1])))> 0) stop("some packages are missing!!")'], stdout=FNULL, stderr=FNULL).returncode
+    if installed == 1:
+      ret.append(f"""Cannot find Pandem2simulator R packages necessary for simulating COVID19 detailed data from ecdc datasets. 
+      You can install this package with the following command:
+        install.packages("devtools")
+        
+      devtools::install_github("maous1/Pandem2simulator")
+      """)
   if settings["pandem"]["source"]["nlp"]["active"] and check_nlp:
      models_path = settings["pandem"]["source"]["nlp"]["models_path"]
      if os.path.exists(models_path):
@@ -151,7 +157,7 @@ def install_issues(check_nlp = True):
        ret.append("""NLP Annotation is active as per settings but the models path has not been found which is necessary to detect the existing models (even when running the server outside PANDEM-2
              You have either set the PANDEM_NLP environment variable to the folder holding the models or set the value pandem.source.nlp.models.path on  {util.pandem_path('settings.yml')}
        """)
-  if are_twitter_credentials_missing():
+  if check_nlp and are_twitter_credentials_missing():
     ret.append(f"""Twitter credentials are necessary since one of your sources uses twitter, but we could not find the credentials
       please try running PANDEM-2 again to provide the right credentials or remove the twitter data source definition on {util.pandem_path("files", "source-definitions")}
       To get twitter credentials please check you have to decralre it. Please check this: https://developer.twitter.com/en/docs/twitter-api/getting-started/getting-access-to-the-twitter-api
@@ -238,5 +244,33 @@ def run_pandem2app():
   threading.Thread(target=run_app).start()
 
 
+def list_sources_dir(p):
+  ret = dict()
+  for f in os.listdir(p):
+   if f.endswith(".json"):
+     with open(os.path.join(p, f)) as fj:
+       js = json.load(fj)
+       if "scope" in js:
+         s, t = (js["scope"].get("source"), js["scope"].get("tags"))
+         ret[s] = t[0] if len(t) > 0 else s
+  return ret
+
+def list_sources(local = True, default = False, missing_local = False, missing_default = False):
+  local_map = list_sources_dir(util.pandem_path("files", "source-definitions"))
+  default_map = list_sources_dir(pkg_resources.resource_filename("pandemsource", os.path.join("data", "DLS")))
   
+  if local and missing_local or default and missing_default:
+    raise ValueError("Cannot lis both missing and existing sources")
+  ret = list()
+  if local:
+    ret.extend(local_map.items())
+  elif missing_local:
+    ret.extend((k, v) for k, v in default_map.items() if k not in local_map)
+  if default:
+    ret.extend(local_map.items())
+  elif missing_default:
+    ret.extend((k, v) for k, v in local_map.items() if k not in defaul_map)
+  return ret
+
+
 
