@@ -34,7 +34,6 @@ class DataframeReader(worker.Worker):
         """Checks if the DLS columns names exist in dataframe
         and if the variable indicated in the column element from dls exists in variables.json files
         and if yes, checks the dataframe variables types, if not as expected in variables.json, raises an issue"""
-
         var=variables
         dls_col_list=[]
         issues = {}
@@ -198,19 +197,12 @@ class DataframeReader(worker.Worker):
             ("action" in t and t["action"] == "insert" or col_types[t["name"]] in ["observation", "indicator", "resource"])
         )
         attr_cols = {}
-        for col  in insert_cols.keys():
+        for col in insert_cols.keys():
           typ = col_types[col]
           if typ in ["observation", "indicator", "resource"]:
             attr_cols[col] =  [k for k, v in col_types.items() if v not in  ["observation", "indicator", "resource"] and types_ok[k]]
           else:
-            attr_cols[col] =  [k for k, v in col_vars.items() if 
-              types_ok[k] and  
-              (
-                (variables[col_vars[col]]["linked_attributes"] is not None and  
-                v in variables[col_vars[col]]["linked_attributes"]) or
-                  col_types[k] in ["characteristic", "not_characteristic", "private", "date", "referential_parent"]
-              )
-            ]
+            attr_cols[col] =  [k for k, v in col_vars.items() if types_ok[k] and v not in  ["observation", "indicator", "resource"] and k != col]
         tuples = []
         for row in range(len(df)):
             for col, group in insert_cols.items():
@@ -255,7 +247,6 @@ class DataframeReader(worker.Worker):
                 tuples.append(tup)
         ret = {"scope":dls["scope"].copy()}
         ret["scope"]["file_name"] = file_name
-
         # validating that globals are property instantiated
         #if "scope" in dls and "globals" in dls["scope"] : 
         #  ret["scope"]["globals"] = self.add_values(dls["scope"]["globals"], tuples = [], issues = issues, dls = dls, job = job, file_name = file_name)
@@ -292,7 +283,7 @@ class DataframeReader(worker.Worker):
               # value is missing we are going to try to get it from tuples
               r["value"] = list(set(x["attrs"][base_var] for x in tuples if base_var in x["attrs"]))
             ret.append(r)
-            
+
             if len(r["value"])==0:
               message = (f"Variable {var['variable']} needs to be instantiated ad per DLS but no values where found on dataset")
               issue = {'step' : job['step'],
@@ -352,16 +343,17 @@ class DataframeReader(worker.Worker):
         return tup
 
     def transform_range(self, value):
-      if '>' in value:
-        a = value.strip().split('>')[1].split('y')[0]
-        b = ''
-      elif '-' in value:
-        a = value.strip().split('-')[0]
-        b = value.strip().split('-')[1].split('y')[0]
+      nb = re.findall('[0-9]+', value)
+      nb_size = len(nb)
+      if nb_size == 0:
+        return None
+      elif nb_size == 1:
+        return f'-{nb[0]}'if int(nb[0]) <= 40 else f'{nb[0]}-'
+      elif nb_size == 2:
+        nb = sorted(list(map(int, nb)))
+        return f'{nb[0]}-{nb[1]}'
       else:
-        a = 0
-        b = value.strip().split('y')[0]
-      return f'{a}-{b}'
+        raise ValueError(f'Too much numbers in list ({nb_size}): {nb}')
 
     def is_numeric_unit(self, unit):
       if unit is None:
